from typing import Literal

Contrast = Literal[
    '0',
    '50',
    '75',
    '100',
    '125',
    '150',
    '200',
]
